pub fn raid_dungeon<const D: u128>(
ctx: &ConditionalProgressCtx<'_>,
) -> Result<i64>Expand description
+1 on a RaidDungeon event for dungeon D, or while the active fight is in
dungeon D; otherwise unchanged.
pub fn raid_dungeon<const D: u128>(
ctx: &ConditionalProgressCtx<'_>,
) -> Result<i64>+1 on a RaidDungeon event for dungeon D, or while the active fight is in
dungeon D; otherwise unchanged.